# xgbse._kaplan_neighbors.XGBSEKaplanNeighbors
::: xgbse._kaplan_neighbors.XGBSEKaplanNeighbors
    handler: python
    rendering:
      show_root_heading: false
      show_source: false

# xgbse._kaplan_neighbors.XGBSEKaplanTree
::: xgbse._kaplan_neighbors.XGBSEKaplanTree
    handler: python
    rendering:
      show_root_heading: false
      show_source: false
